summaryrefslogtreecommitdiff
path: root/service/rpc/service.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
committerWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
commitca95f67317bcf8972b9e669869338a7dc09bf06d (patch)
tree4d199ceb8a78675242fef21bd87efb5a78b04029 /service/rpc/service.go
parentc8e8afe79611941ce50453ee7dfae82d7915e9c4 (diff)
more upload tests
Diffstat (limited to 'service/rpc/service.go')
-rw-r--r--service/rpc/service.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/rpc/service.go b/service/rpc/service.go
index ce1e3351..6e26d3c2 100644
--- a/service/rpc/service.go
+++ b/service/rpc/service.go
@@ -21,9 +21,9 @@ type Service struct {
serving bool
}
// Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.
-func (s *Service) Configure(cfg service.Config, reg service.Container) (enabled bool, err error) {
+func (s *Service) Init(cfg service.Config, reg service.Container) (enabled bool, err error) {
config := &config{}
if err := cfg.Unmarshal(config); err != nil {
return false, err
@@ -21,9 +21,9 @@ type Service struct {
serving bool
}
-// Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
+// Init must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.